<?php
/**
 * @package   woo_affilbox
 * @author    Vladislav Musilek
 * @link      http://toret.cz.cz
 * @copyright 2014 Vladislav Musilek
 */

class Woo_Affilbox {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 *
	 * @var     string
	 */
	const VERSION = '1.3';

	/**
	 * Unique identifier for your plugin.
	 *
	 *
	 * The variable name is used as the text domain when internationalizing strings
	 * of text. Its value should match the Text Domain file header in the main
	 * plugin file.
	 *
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_slug = 'woo-affilbox';

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Initialize the plugin by setting localization and loading public scripts
	 * and styles.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		// Load plugin text domain
		add_action( 'init', array( $this, 'load_plugin_textdomain' ) );

		// Activate plugin when new blog is added
		add_action( 'wpmu_new_blog', array( $this, 'activate_new_site' ) );
		//remove_action( 'woocommerce_thankyou', 'woocommerce_order_details_table', 10 );
		add_filter('woocommerce_thankyou', array( $this, 'converse_code' ) );  

		add_filter('wp_footer',  array( $this, 'tracking_code' ) );
	
  	}

	/**
	 * Return the plugin slug.
	 *
	 * @since    1.0.0
	 *
	 * @return    Plugin slug variable.
	 */
	public function get_plugin_slug() {
		return $this->plugin_slug;
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Fired when the plugin is activated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Activate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       activated on an individual blog.
	 */
	public static function activate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide  ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_activate();
				}

				restore_current_blog();

			} else {
				self::single_activate();
			}

		} else {
			self::single_activate();
		}

	}

	/**
	 * Fired when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Deactivate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       deactivated on an individual blog.
	 */
	public static function deactivate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_deactivate();

				}

				restore_current_blog();

			} else {
				self::single_deactivate();
			}

		} else {
			self::single_deactivate();
		}

	}

	/**
	 * Fired when a new site is activated with a WPMU environment.
	 *
	 * @since    1.0.0
	 *
	 * @param    int    $blog_id    ID of the new blog.
	 */
	public function activate_new_site( $blog_id ) {

		if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
			return;
		}

		switch_to_blog( $blog_id );
		self::single_activate();
		restore_current_blog();

	}

	/**
	 * Get all blog ids of blogs in the current network that are:
	 * - not archived
	 * - not spam
	 * - not deleted
	 *
	 * @since    1.0.0
	 *
	 * @return   array|false    The blog ids, false if no matches.
	 */
	private static function get_blog_ids() {

		global $wpdb;

		// get an array of blog ids
		$sql = "SELECT blog_id FROM $wpdb->blogs
			WHERE archived = '0' AND spam = '0'
			AND deleted = '0'";

		return $wpdb->get_col( $sql );

	}

	/**
	 * Fired for each blog when the plugin is activated.
	 *
	 * @since    1.0.0
	 */
	private static function single_activate() {

	}

	/**
	 * Fired for each blog when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 */
	private static function single_deactivate() {

	}

	/**
	 * Load the plugin text domain for translation.
	 *
	 * @since    1.0.0
	 */
	public function load_plugin_textdomain() {

		$domain = $this->plugin_slug;
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		load_textdomain( $domain, trailingslashit( WP_LANG_DIR ) . $domain . '/' . $domain . '-' . $locale . '.mo' );

	}
  	/**
  	 *
  	 * Send 
  	 *
  	 */           
  	public function converse_code( $order_id ){
		
		$code = stripslashes( get_option( 'affilbox_converse_code' ) );
		$affilbox_count_shipping = stripslashes( get_option( 'affilbox_count_shipping') ); 
	  	
	  	if( !empty( $code ) ){
	  	
	  		$order = wc_get_order( $order_id );

	  		$order_total = $order->get_total(); 
	  		$order_currency = $order->get_currency(); 
  
	  		if( !empty( $order_total ) ) {
			
				$order_tax = $order->get_total_tax();
				if( !empty( $order_tax ) && $order_tax != 0 ){
		  
		  			$order_price = $order_total - $order_tax;
		
				} else {
		
		  			$order_price = $order_total;
		
				}  
	  	
				if( !empty( $affilbox_count_shipping ) && $affilbox_count_shipping == 'yes' ) {
				
					$order_shipping = $order->get_shipping_total();
				
					if( !empty( $order_shipping ) ) {
						$order_price = $order_price - $order_shipping;
					}
			
				}

	  		} 
		
			$code = str_replace( 'CENA', $order_price, $code );
			$code = str_replace( 'ID_TRANSAKCE', $order_id, $code );
			$code = str_replace( 'OZNACENI_MENY', $order_currency, $code );
			echo $code;
  
		}
  	}
  
  	/**
  	 * Display tracking code in footer
  	 *
  	 * @since    1.0.0  
  	 */        
  	public function tracking_code() {
	
   
		$code = stripslashes(get_option( 'affilbox_tracking_code' ));
	  	if( !empty( $code ) ){
			echo $code; 
	  	}
  
  	}




}